<?php

namespace Drupal\subman\Event;

use Symfony\Contracts\EventDispatcher\Event;

/**
 * Event that is fired when a user logs in.
 */
class SubmanIncomingWebhook extends Event {

  const EVENT_NAME = 'subman_incoming_webhook';

  /**
   * The SaaS's name from the webhook URL.
   *
   * @var string
   */
  public $service;

  /**
   * The webhook's name from the webhook URL.
   *
   * @var string
   */
  public $webhook;

  /**
   * The webhook's raw payload data string.
   *
   * @var string
   */
  public $dataRaw;

  /**
   * The webhook's payload data as JSON (if applicable).
   *
   * @var array
   */
  public $dataJson;

  /**
   * Constructs the object.
   *
   * @param string $service
   *   The passed service name from the webhook URL.
   * @param string $webhook
   *   The passed webhook name from the webhook URL.
   * @param string $data_raw
   *   The passed raw string payload data.
   * @param string $data_json
   *   The passed payload data as JSON (if applicable).
   */
  public function __construct($service, $webhook, $data_raw, $data_json) {
    $this->service = $service;
    $this->webhook = $webhook;
    $this->dataRaw = $data_raw;
    $this->dataJson = $data_json;
  }

}
