<?php

namespace Drupal\subman\Event;

use Symfony\Contracts\EventDispatcher\Event;

/**
 * Event that is fired when a subscriber is changed in Drupal.
 */
class SubmanSubscriberModified extends Event {

  const EVENT_NAME = 'subman_subscriber_modified';

  const OP_CREATED = 'created';
  const OP_UPDATED = 'updated';
  const OP_DELETED = 'deleted';

  /**
   * The affected entity modeling the subscriber.
   *
   * @var \Drupal\Core\Entity\ContentEntityBase
   */
  public $subscriber;

  /**
   * The operation describing the change to the entity, see OP_* constants.
   *
   * @var string
   */
  public $operation;

  /**
   * Constructs the object.
   *
   * @param \Drupal\Core\Entity\ContentEntityBase $subscriber
   *   The affected entity modeling the subscriber.
   * @param string $operation
   *   The operation describing the change to the entity, see OP_* constants.
   */
  public function __construct($subscriber, $operation = self::OP_UPDATED) {
    $this->subscriber = $subscriber;
    $this->operation = $operation;
  }

}
