<?php

namespace Drupal\subman\Event;

use Symfony\Component\HttpFoundation\Request;
use Symfony\Contracts\EventDispatcher\Event;

/**
 * Event that is fired when a user logs in.
 */
class SubmanSynchronousResult extends Event {

  const EVENT_NAME = 'subman_synchronous_result';

  /**
   * The request the event was triggered by.
   *
   * @var \Symfony\Component\HttpFoundation\Request
   */
  public $request;

  /**
   * Any differentiator the event might have been triggered with.
   *
   * @var string
   */
  public $differentiator;

  /**
   * The Url to redirect to after the event is handled.
   *
   * Will be preset (if one is configured) and changed during event handling.
   *
   * @var string
   */
  public $redirectUrl;

  /**
   * Constructs the object.
   *
   * @param string $differentiator
   *   Any URL differentiator that the URL might have specified.
   * @param \Symfony\Component\HttpFoundation\Request $request
   *   The request this event was triggered by.
   * @param string $redirect_url
   *   The Url to redirect to after the event is handled.
   */
  public function __construct($differentiator, Request $request, $redirect_url) {
    $this->differentiator = $differentiator;
    $this->request = $request;
    $this->redirectUrl = $redirect_url;
  }

}
