<?php

namespace Drupal\subman;

use Drupal\Component\Serialization\Json;

/**
 * Class defining subman webhook exceptions.
 */
class SubmanWebhookException extends \Exception {

  const dataMissing = [
    'http_status' => 500,
    'message_prefix' => 'Data missing',
  ];

  const unsupportedEvent = [
    'http_status' => 500,
    'message_prefix' => 'Event unsupported',
  ];

  const subscriberMissOrConflict = [
    'http_status' => 500,
    'message_prefix' => 'Subscriber entity could not be found or created (conflicting email?).',
  ];

  const apiError = [
    'http_status' => 422,
    'message_prefix' => 'Error returned from API',
  ];

  /**
   * {@inheritdoc}
   */
  public function __construct($type, $additional_message = NULL) {
    if ($additional_message && !is_string($additional_message)) {
      $additional_message = Json::encode($additional_message);
    }
    $message = implode(': ', [$type['message_prefix'], $additional_message]);
    $code = $type['http_status'] ?? 500;
    parent::__construct($message, $code);
  }

  /**
   * Throws an exception if the data is empty.
   */
  public static function throwOnEmpty($data, $data_name = NULL) {
    if (empty($data)) {
      throw new SubmanWebhookException(SubmanWebhookException::dataMissing, $data_name);
    }
  }

}
